#!/usr/bin/ksh
#******************************************************************************
# (rxsprint.sh)  FTP Shell Script for PRINTS to the RxServer
# Last Update: 11/15/00 lsl Added HP-UX to checkping function and script 
#                           location.
#              10/31/00 lsl Added checkping for different OS versions
#              06/06/00 lsl Added chk for correct # of params
#                           Added set -x for tracing script
#                           Added functions: checkftp - to validate ftp status
#                                            email - to send an email err msg
#              05/25/00 lsl added parsing for $1 to chk for debug flag on/off
#                           added debug log file output to /tmp/rxlaser.log
#                           rxdebug.print, rxdebug.ftpscript
#              05/08/00 lsl Added grep and tmpfile
#              03/17/99 mm
#              10/22/02 rgm TB e9793 changes for invoice signature prints
#              12/09/03 rgm; TB# e19108 multi-debug logging
#              01/02/04 rgm; TB# e19222 Linux ping changes
# 	           01/22/04 rgm; TB# e19430 don't use hardcoded ping tmp dir
#
# $1 - We pass the name of the printer device we want to appear in the header
#      information for RxServer.  This is passed as a parameter on the
#      sasp. command line (ie: rxsprint.sh WHS1PRT[:debug]).
#
# $2 - Trend passes the full path name of the temporary print file
#
# Assumptions: that grep and ftp are in a public path and they have permissions
# set all for users and/or a system process that may call this script.
#******************************************************************************

# unremark the next line to debug this script (turns on trace)
# set -x

DIRTEMP1=`basename $2`      
DIRTEMP4=`dirname $2`       

# Run UnForm version of this script
# Change path to match your system
/usr/unform71/uf_rxsprint.sh $1 $2 

# When ready to turn off this script
# Remove # in front of next line
# exit

#***************************** FUNCTION START *********************************
function checkping
{
     # check ping messages for errors.  Ping results vary depending on OS version
     # AIX version
     if uname | grep 'AIX' > /dev/null; then
          if ping -c 5 $NTSERVER | grep '100% packet loss' >> /rd/tmp/$$.TMP;  then
               email # a function call
               print 1
          else 
               print 0
          fi
     # dgux Version
     elif uname | grep 'dgux' > /dev/null; then
          if ping $NTSERVER 5 | grep 'no answer from '$NTSERVER >> /rd/tmp/$$.TMP;  then
              email # a function call
              print 1
          else
              print 0
          fi
     # HP UX Version
     elif uname | grep 'HP-UX' > /dev/null; then
          if ping $NTSERVER -n 5 | grep 'no answer from '$NTSERVER >> /rd/tmp/$$.TMP;  then
              email # a function call
              print 1
          else
              print 0
          fi
     # UnixWare Version
     elif uname | grep 'UnixWare' > /dev/null; then
          if ping $NTSERVER 5 | grep 'no answer from '$NTSERVER >> /rd/tmp/$$.TMP;  then
              email # a function call
              print 1
          else
              print 0
          fi
     # Linux Version
     elif uname | grep 'Linux' > /dev/null; then
          if ping -c 5 $NTSERVER | grep 'no answer from '$NTSERVER >> /rd/tmp/$$.TMP; then      
              email # a function call          
              print 1          
          else          
              print 0          
          fi          

     # Yet some other version of UNIX, so we will assume syntax of: ping host timeout
     else
          if ping $NTSERVER 5 | grep 'no answer from '$NTSERVER >> /rd/tmp/$$.TMP;  then
              email # a function call
              print 1
          else
              print 0
          fi
     fi
}
#******************************************************************************

#***************************** FUNCTION START *********************************
function checkftp
{
     # check quoted messages from ftp output for errors,they may need to change
     # if a different version of FTP is used.

     if grep 'The system cannot find the file specified' $1 > /dev/null; then
          print 1
     elif grep 'Please login with USER and PASS' $1 > /dev/null; then
          print 1
     else
          print 0
     fi
}
#******************************************************************************

#***************************** FUNCTION START *********************************
function email
{
     # send error message as email to the $MAIL_TO
     echo 'FTP Failed' >> /rd/tmp/$$.TMP
     # may need to use a different mail program if this one is not there
     #################################################################
     # mailx command params:                                         #
     #         -s = set subject to string                            #
     #                                                               #
     #################################################################
     mailx -s 'ERROR: FTP Problem on RxServer or UNIX box' $MAIL_TO < /rd/tmp/$$.TMP
}
#******************************************************************************

#********************FUNCTION START********************************************
function ftpsigs
{

for SIGFILE in `ls $DIRTEMP4/$SIGDIR/`             
do                                                 
TEMPSIGFILE=$SIGFILE$SIGDIR$SIGAPP                 
SIGFILE2=$DIRTEMP4/$SIGDIR/$SIGFILE                
echo 'put' $SIGFILE2 $TEMPSIGFILE >> $FTPSCRIPT      
done                                               

}


#******************************************************************************

############################### MAIN PRG START ################################
# check for correct params passed to script
PN=`basename $0`            # Program name
DN=`dirname $0`             # Directory Path
VER=`echo '$Revision: 1.1 $' | cut -d' ' -f2`

# check for at least 2 params and that the second one is a readable file
# could maybe use -s instead of -r
if [ \( $# -lt 2 \) ]
then
    echo 'Script Location:' $DN
    echo >&2 'usage: '$PN' RxServer_Printer_Name[:debug] filename'
    exit 1
fi

#****************************** SET VARIABLES  ********************************
# THE FOLLOWING 6 VARIABLES MAY CHANGE WITH EACH CLIENT INSTALLATION
# Insert IP address for NT Server here
NTSERVER=192.168.69.21

# Insert user name for NT Server here - IF REQUIRED
USER=rxprinter1

# Insert password for NT Server here - IF REQUIRED
PASSWD=AgH1000

# Insert the name of the NT Server remote directory here
REMOTEDIR=\poll

# Log file name
LOGFILE=/rd/tmp/rxlaser.log

# whom to email error messages to
MAIL_TO=steveb@mcesi.com

#****************************************************************************

# Name of temporary ftp script file used by ftp to send output to
# the RxServer
FTPSCRIPT=/rd/tmp/$$.ftp

# Full path of new temporary print file
PRINTFILE=/rd/tmp/rxs_$$.tmp

# parse the $1 Parameter for :debug
PRINTERNAME=$1

# set the initial value for the var used in the check for ftp status
isok=1

# initialize conditional flag variables
DEBUG_LOG=0
MULTI_LOG=0

# grep the first param for the :debug to see if debugging is enabled
if echo $1 | grep ':' > /dev/null
then
    PRINTERNAME=`echo $1 | cut -d: -f1`
    DebugTest=`echo $1 | cut -d: -f2`
    if [ $DebugTest = 'debug' ]; then DEBUG_LOG=1; fi
    if [ $DebugTest = 'multifile' ]; then DEBUG_LOG=1; MULTI_LOG=1; fi
fi

# Create our own copy of the temporary file because Trend deletes
# it too quickly
echo $PRINTERNAME > $PRINTFILE                       # Create header info
cat $2 >> $PRINTFILE

# set the default name for print file used as the destination file name on
# the NT Server
TEMPFILE=rxs_$$.000

# grep file to rename file extension as used by the associations (doc grouping)
# in rxserver
if grep 'Pick Ticket' $PRINTFILE > /dev/null;then TEMPFILE=rxs_$$.pt
     elif grep 'Order Acknowledgement' $PRINTFILE > /dev/null; then TEMPFILE=rxs_$$.ack
     elif grep 'Purchase Order' $PRINTFILE > /dev/null; then TEMPFILE=rxs_$$.po
     elif grep 'APCHK' $PRINTFILE > /dev/null; then TEMPFILE=rxs_$$.chk
     elif grep 'APCHKREM' $PRINTFILE > /dev/null; then TEMPFILE=rxs_$$.ra
     elif grep 'Bill Of Lading' $PRINTFILE > /dev/null; then TEMPFILE=rxs_$$.bol
     elif grep 'Statement' $PRINTFILE > /dev/null; then TEMPFILE=rxs_$$.sta
     elif grep 'Transfer' $PRINTFILE > /dev/null; then TEMPFILE=rxs_$$.wt
     elif grep 'Invoice' $PRINTFILE > /dev/null; then TEMPFILE=rxs_$$.inv
fi

export NTSERVER USER PASSWD FTPSCRIPT REMOTEDIR PRINTFILE TEMPFILE

#****************************************************************************
# create the new ftp script
> $FTPSCRIPT

# add ftp commands to the script

# open connection to the NT Server
echo 'open' $NTSERVER >>$FTPSCRIPT

# login to the NT Server if required
echo 'user' $USER $PASSWD >>$FTPSCRIPT

# start binary transfer mode
echo 'binary' >>$FTPSCRIPT

# copy the file to the NT Server
echo 'cd' $REMOTEDIR >>$FTPSCRIPT

# do bitmaps first of available
SIGDIR=`echo $DIRTEMP1 | sed 's/\.//g' `
SIGAPP=.pcl
if [ -d $DIRTEMP4/$SIGDIR/ ]
then

ftpsigs

fi

echo 'put' $PRINTFILE $TEMPFILE >>$FTPSCRIPT

# close connection to the NT Server
echo 'close' >>$FTPSCRIPT

#****************************************************************************
# if debug mode then check for FTP fail or succeed
# and create debug log files
if [ DEBUG_LOG -eq 1 ]
then
     # append new lines to the tmp logfile
     echo '*****************************************************************************' > /rd/tmp/$$.TMP

     # Put the who am i info and date/time in tmp LogFile
     echo 'UNIX Login:' `who am i | cut -d' ' -f1` 'Date:' `date` >> /rd/tmp/$$.TMP
     echo 'FTPing:' $PRINTFILE 'TO File: /'$REMOTEDIR'/'$TEMPFILE >> /rd/tmp/$$.TMP
     echo 'RxServer IP:' $NTSERVER 'User:' $USER 'Password:' $PASSWD >> /rd/tmp/$$.TMP

     # use ping check to see if correct IP address was given
     isok=`checkping`
     if [ isok -eq 0 ]
     then
          # run the ftp command using the new script file
          # also send output and errors to /rd/tmp/$$.TMP
          # which gets sent as email and appended to the log file

          #################################################################
          # ftp command params:                                           #
          #         -i = turn off interactive prompting during            #
          #              multiple file transfers.                         #
          #                                                               #
          #         -n = disables the 'auto-login' feature                #
          #################################################################
          ftp -in <$FTPSCRIPT >> /rd/tmp/$$.TMP 2>>/rd/tmp/$$.TMP

          # Check the ftp returned status results
          isok=`checkftp /rd/tmp/$$.TMP` # a function call
          if [ isok -eq 1 ]
          then
               email # a function call
          else
               echo 'FTP Succeeded' >> /rd/tmp/$$.TMP
          fi
     fi

     # build log file from tmp file
     cat /rd/tmp/$$.TMP >> $LOGFILE
     # copy the ftp script and temp file to debug files
     cp $FTPSCRIPT /rd/tmp/rxdebug.ftpscript
     cp $PRINTFILE /rd/tmp/rxdebug.print
     rm /rd/tmp/$$.TMP
else
     # we are not in debug mode so just send the file
     ftp -in <$FTPSCRIPT > /dev/null

fi

if [ MULTI_LOG -eq 1 ] 
then

  if [ -d /rd/tmp/logfile/ ]
  then
   MULTI_LOG=1
  else
    mkdir /rd/tmp/logfile > /dev/null >> /dev/null
  fi

cp $PRINTFILE /rd/tmp/logfile

fi

# remove up all the temp files
rm $FTPSCRIPT
rm $PRINTFILE

if [ -d /rd/tmp/$SIGDIR/ ] 
then

rm /rd/tmp/$SIGDIR/*
rmdir /rd/tmp/$SIGDIR

fi

